@@ -21,7 +21,7 @@
 #include <stdexcept>
 
 #include "battlemaptab.h"
-#include "iunitsync.h"
+#include "springunitsync.h"
 #include "ui.h"
 #include "user.h"
 #include "battle.h"
@@ -151,12 +151,12 @@ void BattleMapTab::Update()
 
 	UnitSyncMap map = m_battle->LoadMap();
 
-	m_map_opts_list->SetItem( 0, 1, wxString::Format( _T( "%dx%d" ), map.info.width / 512, map.info.height / 512 ) );
-	m_map_opts_list->SetItem( 1, 1, wxString::Format( _T( "%d-%d" ), map.info.minWind, map.info.maxWind ) );
-	m_map_opts_list->SetItem( 2, 1, wxString::Format( _T( "%d" ), map.info.tidalStrength ) );
-	m_map_opts_list->SetItem( 3, 1, wxString::Format( _T( "%d" ), map.info.gravity ) );
-	m_map_opts_list->SetItem( 4, 1, wxString::Format( _T( "%d" ), map.info.extractorRadius ) );
-	m_map_opts_list->SetItem( 5, 1, wxString::Format( _T( "%.3f" ), map.info.maxMetal ) );
+	m_map_opts_list->SetItem( 0, 1, wxFormat( _T( "%dx%d" ) ) % (map.info.width / 512) % (map.info.height / 512) );
+	m_map_opts_list->SetItem( 1, 1, wxFormat( _T( "%d-%d" ) ) % map.info.minWind % map.info.maxWind );
+	m_map_opts_list->SetItem( 2, 1, wxFormat( _T( "%d" ) ) % map.info.tidalStrength );
+	m_map_opts_list->SetItem( 3, 1, wxFormat( _T( "%d" ) ) % map.info.gravity );
+	m_map_opts_list->SetItem( 4, 1, wxFormat( _T( "%d" ) ) % map.info.extractorRadius );
+	m_map_opts_list->SetItem( 5, 1, wxFormat( _T( "%.3f" ) ) % map.info.maxMetal );
 
 	int index = m_map_combo->FindString( map.name );
 	if ( index == wxNOT_FOUND ) return;
@@ -271,9 +271,9 @@ void BattleMapTab::OnMapBrowse( wxCommandEvent& /*unused*/ )
 void BattleMapTab::OnStartTypeSelect( wxCommandEvent& /*unused*/ )
 {
 	if ( !m_battle ) return;
-	wxString pos = wxString::Format( _T( "%d" ), m_start_radios->GetSelection() );
+	wxString pos = wxFormat( _T( "%d" ) ) % m_start_radios->GetSelection();
 	m_battle->CustomBattleOptions().setSingleOption( _T( "startpostype" ), pos, OptionsWrapper::EngineOption );
-	m_battle->SendHostInfo( wxString::Format( _T( "%d_startpostype" ), OptionsWrapper::EngineOption ) );
+	m_battle->SendHostInfo( wxFormat( _T( "%d_startpostype" ) ) % OptionsWrapper::EngineOption );
 }
 
 
