@@ -114,7 +114,7 @@ wxString ChannelListctrl::GetInfo()
 {
     int displayed = GetItemCount();
     int total = m_data.size();
-    return wxString::Format( _("Displaying %d out of %d channels"), displayed, total );
+	return wxFormat( _("Displaying %d out of %d channels") ) % displayed % total;
 }
 
 void ChannelListctrl::FilterChannel( const wxString& partial )
