@@ -4,7 +4,7 @@
 #include "filelistctrl.h"
 #include "filelistfilter.h"
 
-#include "../iunitsync.h"
+#include "../springunitsync.h"
 #include "../utils/conversion.h"
 #include "../utils/downloader.h"
 #include <wx/sizer.h>
@@ -80,7 +80,7 @@ void FileListDialog::UpdateList( GlobalEvents::GlobalEventData )
 //        if ( !m_filter->DoFilterResource( *i ) )
             m_filelistctrl->AddFile( &(*i) );
     }
-    m_filecount->SetLabel( wxString::Format( _("%u files displayed"), m_filelistctrl->GetItemCount() ) );
+	m_filecount->SetLabel( wxFormat( _("%u files displayed") ) % m_filelistctrl->GetItemCount() );
     m_filelistctrl->SortList();
 }
 
