@@ -7,9 +7,10 @@ class wxBoxSizer;
 class wxGradientButton;
 
 #include "../simpleinterface/customizedframe.h"
+#include "../utils/mixins.hh"
 
 //! substitute for MainWindow when SpringLobby runs in simple mode
-class SimpleFront : public CustomizedFrame
+class SimpleFront : public CustomizedFrame, public SL::NonCopyable
 {
 protected:
 	// Handlers for SimpleFrontBase events.
