@@ -1,6 +1,7 @@
 #include "statusbar.h"
 #include "../updater/updatehelper.h"
 #include "../utils/platform.h"
+#include "../utils/conversion.h"
 
 Statusbar::Statusbar( wxWindow* parent )
 	:wxStatusBar( parent, wxNewId() ),
@@ -10,9 +11,9 @@ Statusbar::Statusbar( wxWindow* parent )
 {
 	int w[3] = {-1,-1,120};
 	SetFieldsCount( 3, w );
-	PushStatusText( wxString::Format( _T("%s %s"),
-									  GetAppName().c_str(),
-									  GetSpringLobbyVersion().c_str() ),
+	PushStatusText( wxFormat( _T("%s %s") )
+									  % GetAppName()
+									  % GetSpringLobbyVersion(),
 					1 );
 }
 
