@@ -16,6 +16,7 @@
 #include "settings.h"
 #include "utils/customdialogs.h"
 #include "utils/controls.h"
+#include "utils/platform.h"
 #include "aui/auimanager.h"
 #include "ui.h"
 #include "mainwindow.h"
@@ -88,14 +89,20 @@ LobbyOptionsTab::LobbyOptionsTab(wxWindow* parent)
     m_editor_box_sizer->Add( m_editor_loc_sizer, 0, wxEXPAND | wxALL, 2 );
 ////////
     wxStaticBoxSizer* m_autojoin_sizer= new wxStaticBoxSizer ( wxVERTICAL, this, _("Autoconnect") );
-    m_autoconnect_label = new wxStaticText ( this, -1, _("If checked, SpringLobby will automatically log on to the last used server") );
+	m_autoconnect_label = new wxStaticText ( this,
+											 -1,
+											 IdentityString( _("If checked, %s will automatically log on to the last used server") )
+											 );
     m_autojoin = new wxCheckBox( this, -1, _("Autoconnect on lobby start"), wxDefaultPosition, wxDefaultSize, 0 );
     m_autojoin->SetValue( sett().GetAutoConnect() );
     m_autojoin_sizer->Add( m_autoconnect_label, 1, wxEXPAND | wxALL, 5 );
     m_autojoin_sizer->Add( m_autojoin, 0, wxEXPAND | wxALL, 5 );
 
     wxStaticBoxSizer* m_reportstats_sizer = new wxStaticBoxSizer ( wxVERTICAL, this, _("Report statistics") );
-    m_reportstats_label = new wxStaticText ( this, -1, _("By default SpringLobby will send some statistics (OS,SpringLobby version) to server,\nto both make helping you in case of problems easier and inform of critical updates.\nUncheck to disable.") );
+	m_reportstats_label = new wxStaticText ( this,
+											 -1,
+											 IdentityString( _("By default %s will send some statistics (OS,lobby version) to server,\nto both make helping you in case of problems easier and inform of critical updates.\nUncheck to disable.") )
+											 );
     m_reportstats = new wxCheckBox( this, -1, _("report statistics"), wxDefaultPosition, wxDefaultSize, 0 );
     m_reportstats->SetValue( sett().GetReportStats() );
     m_reportstats_sizer->Add( m_reportstats_label, 1, wxEXPAND|wxALL, 5);
@@ -108,7 +115,10 @@ LobbyOptionsTab::LobbyOptionsTab(wxWindow* parent)
 
 #ifdef __WXMSW__
     wxStaticBoxSizer* m_updater_sizer = new wxStaticBoxSizer ( wxVERTICAL, this, _("Automatic updates") );
-    m_updater_label = new wxStaticText ( this, -1, _("SpringLobby can check at startup if a newer version is available and automatically download it for you.") );
+	m_updater_label = new wxStaticText ( this,
+										 -1,
+										 IdentityString( _("%s can check at startup if a newer version is available and automatically download it for you.") )
+										 );
     m_updater = new wxCheckBox( this, -1, _("automatically check for updates"), wxDefaultPosition, wxDefaultSize, 0 );
     m_updater->SetValue( sett().GetAutoUpdate() );
     m_updater_sizer->Add( m_updater_label, 1, wxEXPAND|wxALL, 5);
@@ -121,7 +131,7 @@ LobbyOptionsTab::LobbyOptionsTab(wxWindow* parent)
     m_show_tooltips = new wxCheckBox( this, -1, _("Show Tooltips?"), wxDefaultPosition, wxDefaultSize, 0 );
     m_show_tooltips->SetValue( sett().GetShowTooltips() );
 #ifndef __WXMSW__ // on windows this change is immediate
-    m_show_tooltips_label = new wxStaticText ( this, -1, _("Requires SpringLobby restart to take effect.") );
+	m_show_tooltips_label = new wxStaticText ( this, -1, IdentityString( _("Requires %s restart to take effect.") ) );
     m_show_tooltips_sizer->Add( m_show_tooltips_label, 1, wxEXPAND|wxALL, 5);
 #endif
     m_show_tooltips_sizer->Add( m_show_tooltips, 0, wxEXPAND|wxALL, 5);
