@@ -5,7 +5,7 @@
 #include <wx/string.h>
 
 #include "ibattle.h"
-#include "iunitsync.h"
+#include "springunitsync.h"
 
 class wxPanel;
 class wxBitmap;
@@ -222,13 +222,13 @@ class MapCtrl : public wxPanel
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-2010
+    Copyright (C) 2007-2011
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
-    springsettings is distributed in the hope that it will be useful,
+    SpringLobby is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
