@@ -1,11 +1,12 @@
 #ifndef MMOPTIONSORAPPER_H_
 #define MMOPTIONSORAPPER_H_
 
-#include "iunitsync.h"
+#include "springunitsync.h"
 
 #include <vector>
 #include <utility>
 #include <wx/string.h>
+#include <boost/shared_ptr.hpp>
 
 struct GameOptions;
 
@@ -33,7 +34,7 @@ class mmSectionTree
         typedef std::map< wxString, mmOptionSection > SectionMap;
         SectionMap m_section_map;
         typedef wxFileConfig ConfigType;
-        ConfigType* m_tree;
+		boost::shared_ptr<ConfigType> m_tree;
 
         void AddSection ( const wxString& path, const mmOptionSection& section );
         wxString FindParentpath ( const wxString& parent_key );
@@ -159,7 +160,7 @@ public:
 	GameOptionsMap m_opts;
 
 	//! after loading sections into map, parse them into tree
-	void ParseSectionMap( mmSectionTree& section_tree, const IUnitSync::OptionMapSection& section_map );
+	void ParseSectionMap( mmSectionTree& section_tree, const SpringUnitSync::OptionMapSection& section_map );
 
 	//! Merge this another wrapper's options into this one, with the other'soptions taking precendence
 	bool MergeOptions( const OptionsWrapper& other, GameOption merge_into );
@@ -181,13 +182,13 @@ protected:
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-2010
+    Copyright (C) 2007-2011
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
-    springsettings is distributed in the hope that it will be useful,
+    SpringLobby is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
