@@ -21,16 +21,28 @@
 
 #include <QApplication>
 
+class BattlelistModel;
+class TASServer;
+
 class SasiApp : public QApplication
 {
 	Q_OBJECT
 public:
 	explicit SasiApp(int argc, char *argv[]);
+	bool CmdInit();
+	~SasiApp();
 
 	int exec();
 
 signals:
 	void appLoaded();
+
+public slots:
+//	void Update();
+
+private:
+//	BattlelistModel* bl_model;
+//  TASServer* m_server;
 };
 
 #endif // SASI_APP_H
