@@ -26,6 +26,7 @@
 #ifdef HAVE_WX29
 	#include <wx/colourdata.h>
 #endif
+#include <set>
 
 #include "nonportable.h"
 #include "utils/conversion.h"
@@ -44,6 +45,7 @@
 #ifdef SL_DUMMY_COL
     #include "utils/customdialogs.h"
 #endif
+#include "utils/pathlistfactory.h"
 
 #ifdef __WXMSW__
 	#define BIN_EXT _T(".exe")
@@ -81,7 +83,7 @@ Settings::Settings()
 	{
 		if ( !wxFileName::FileExists( localfilepath ) || !wxFileName::IsFileWritable( localfilepath ) )
 		{
-			//either local conf file soes not exist, or it exists but is not writable
+            //either local conf file does not exist, or it exists but is not writable
 			m_chosen_path = userfilepath;
 			SetPortableMode( false );
 		}
@@ -727,56 +729,6 @@ void Settings::SetWindowPos( const wxString& window, const wxPoint& pos )
 
 // ========================================================
 
-wxPathList Settings::GetAdditionalSearchPaths( wxPathList& pl )
-{
-	wxPathList ret;
-	wxStandardPathsBase& sp = wxStandardPathsBase::Get();
-
-	pl.Add( wxFileName::GetCwd() );
-	pl.Add( sp.GetExecutablePath().BeforeLast( sep ) );
-	pl.Add( wxFileName::GetHomeDir() );
-#ifndef SL_QT_MODE
-	pl.Add( sp.GetUserDataDir().BeforeLast( sep ) );
-	pl.Add( sp.GetDataDir().BeforeLast( sep ) );
-	pl.Add( sp.GetResourcesDir().BeforeLast( sep ) );
-#endif
-	pl.Add( wxGetOSDirectory() );
-
-#ifdef __WXMSW__
-	pl.Add( sp.GetDocumentsDir() + sepstring + wxT("My Games") + sepstring + wxT("Spring") );
-	//maybe add more here like:
-	//Appdata + \Spring
-	//Mydocs + \Spring
-
-	//http://projects.springlobby.info/issues/1530
-	wxRegKey base( _T("HKLM\\Software\\Spring") );
-	wxString usync_keyval = GetRegkeyVal( base, _T("SpringEngineHelper"), wxString() );
-	if ( usync_keyval != wxEmptyString )
-	{
-		pl.Add( usync_keyval.BeforeLast( sep ) );
-	}
-	wxString binary_keyval = GetRegkeyVal( base, _T("SpringEngine"), wxString() );
-	if ( binary_keyval != wxEmptyString )
-	{
-		pl.Add( binary_keyval.BeforeLast( sep ) );
-	}
-
-#endif
-
-	for ( size_t i = 0; i < pl.GetCount(); i++ )
-	{
-		wxString path = pl[i];
-		if ( !path.EndsWith( sepstring ) )
-            path += sepstring;
-		ret.Add( path );
-		ret.Add( path + _T( "Spring" ) + sepstring );
-		ret.Add( path + _T( "spring" ) + sepstring );
-		ret.Add( path + _T( "games" ) + sepstring + _T( "Spring" ) + sepstring );
-		ret.Add( path + _T( "games" ) + sepstring + _T( "spring" ) + sepstring );
-	}
-	return ret;
-}
-
 wxString Settings::AutoFindSpringBin()
 {
 	wxPathList pl;
@@ -784,41 +736,13 @@ wxString Settings::AutoFindSpringBin()
 	pl.AddEnvList( _T( "%ProgramFiles%" ) );
 	pl.AddEnvList( _T( "PATH" ) );
 
-	pl = GetAdditionalSearchPaths( pl );
+    pl = PathlistFactory::AdditionalSearchPaths( pl );
 
 	return pl.FindValidPath( SPRING_BIN );
 }
 
-
-wxPathList Settings::GetConfigFileSearchPathes()
+wxString Settings::AutoFindUnitSync(wxPathList pl) const
 {
-	wxPathList pl;
-
-	pl.AddEnvList( _T( "%ProgramFiles%" ) );
-
-	pl.AddEnvList( _T( "LDPATH" ) );
-	pl.AddEnvList( _T( "LD_LIBRARY_PATH" ) );
-
-	pl.Add( _T( "/usr/local/lib/spring" ) );
-	pl.Add( _T( "/usr/local/lib64" ) );
-	pl.Add( _T( "/usr/local/games" ) );
-	pl.Add( _T( "/usr/local/games/lib" ) );
-	pl.Add( _T( "/usr/local/lib" ) );
-	pl.Add( _T( "/usr/lib64" ) );
-	pl.Add( _T( "/usr/lib" ) );
-	pl.Add( _T( "/usr/lib/spring" ) );
-	pl.Add( _T( "/usr/games" ) );
-	pl.Add( _T( "/usr/games/lib64" ) );
-	pl.Add( _T( "/usr/games/lib" ) );
-
-	pl = GetAdditionalSearchPaths( pl );
-
-	return pl;
-}
-
-wxString Settings::AutoFindUnitSync()
-{
-	wxPathList pl = GetConfigFileSearchPathes();
 	wxString retpath = pl.FindValidPath( _T( "unitsync" ) + GetLibExtension() );
 	if ( retpath.IsEmpty() )
 		retpath = pl.FindValidPath( _T( "libunitsync" ) + GetLibExtension() );
@@ -827,13 +751,13 @@ wxString Settings::AutoFindUnitSync()
 
 wxString Settings::AutoFindBundle()
 {
-	wxPathList pl = GetConfigFileSearchPathes();
+    wxPathList pl = PathlistFactory::ConfigFileSearchPaths();
 	return pl.FindValidPath( _T( "Spring.app" ) );
 }
 
 wxString Settings::AutoFindUikeys()
 {
-	wxPathList pl = GetConfigFileSearchPathes();
+    wxPathList pl = PathlistFactory::ConfigFileSearchPaths();
 	return pl.FindValidPath( _T( "uikeys.txt" ) );
 }
 
@@ -947,6 +871,8 @@ wxString Settings::GetCurrentUsedDataDir()
 	if ( dir.IsEmpty() )
         dir = GetExecutableFolder(); // fallback
 #else
+    if ( IsPortableMode() )
+        dir = GetExecutableFolder();
 	if ( dir.IsEmpty() )
         dir = wxFileName::GetHomeDir() + sepstring + _T( ".spring" ); // fallback
 #endif
@@ -964,10 +890,9 @@ wxString Settings::GetCurrentUsedSpringBinary()
 	else return GetSpringBinary( GetCurrentUsedSpringIndex() );
 }
 
-
 wxString Settings::GetCurrentUsedUnitSync()
 {
-	if ( IsPortableMode() ) return GetCurrentUsedDataDir() + sepstring + _T( "unitsync" ) + GetLibExtension();
+    if ( IsPortableMode() ) return AutoFindUnitSync( PathlistFactory::fromSinglePath( GetCurrentUsedDataDir() ) );
 	else if ( GetSearchSpringOnlyInSLPath() ) return GetExecutableFolder() + sepstring + _T( "unitsync" ) + GetLibExtension();
 	else if ( GetUseSpringPathFromBundle() ) return GetExecutableFolder() + sepstring + _T("unitsync") + GetLibExtension();
 	else return GetUnitSync( GetCurrentUsedSpringIndex() );
@@ -1357,7 +1282,7 @@ void Settings::SetDisplayJoinLeave( bool display, const wxString& channel  )
 
 bool Settings::GetDisplayJoinLeave( const wxString& channel  )
 {
-	return m_config->Read( _T( "/Channels/DisplayJoinLeave/" ) +  channel, true );
+    return m_config->Read( _T( "/Channels/DisplayJoinLeave/" ) +  channel, 0l );
 }
 
 
@@ -1597,21 +1522,36 @@ bool Settings::GetUseIrcColors()
 	return m_config->Read( _T( "/Chat/UseIrcColors" ), true );
 }
 
+void Settings::setFromList(const wxArrayString& list, const wxString& path)
+{
+    wxString string;
+    for ( unsigned int i = 0; i < list.GetCount(); i++ )
+        string << list[i] << _T( ";" );
+    m_config->Write( path, string );
+}
+
+wxArrayString Settings::getFromList(const wxString& path)
+{
+    return wxStringTokenize( m_config->Read( path, wxString() ), _T(";") );
+}
 
 void Settings::SetHighlightedWords( const wxArrayString& words )
 {
-	if ( m_config->Exists( _T( "/Chat/HighlightedWords" ) ) ) // flush existing entries
-		m_config->DeleteGroup( _T( "/Chat/HighlightedWords" ) );
-
-	for ( unsigned int i = 0; i < words.GetCount(); i++ )
-	{
-		m_config->Write( _T( "/Chat/HighlightedWords/" ) + words[i], words[i] );
-	}
+    setFromList( words, _T("/Chat/HighlightedWords") );
 }
 
 wxArrayString Settings::GetHighlightedWords()
 {
-	return GetEntryList( _T( "/Chat/HighlightedWords" ) );
+    return getFromList( _T("/Chat/HighlightedWords") );
+}
+
+void Settings::ConvertLists()
+{
+    const wxArrayString current_hl = GetEntryList( _T( "/Chat/HighlightedWords" ) );
+    m_config->DeleteGroup( _T( "/Chat/HighlightedWords" ) );
+    SaveSettings();
+    SetHighlightedWords( current_hl );
+    SaveSettings();
 }
 
 void Settings::SetRequestAttOnHighlight( const bool req )
@@ -2586,7 +2526,7 @@ bool Settings::GetBroadcastEverywhere()
 
 void Settings::SetBroadcastEverywhere(bool value)
 {
-	m_config->Write( _T("/Chat/BroadcastEverywhere"), value);
+    m_config->Write( _T("/Chat/BroadcastEverywhere"), value);
 }
 
 //Hotkeys stuff (for springsettings)
@@ -2679,3 +2619,23 @@ bool Settings::IsSelfUpdateDisabled()
 	return m_config->Read( _T( "/General/SelfUpdateDisabled" ), 0l );
 }
 
+std::set<int> Settings::KnownMatchmakerCPU()
+{
+    const wxArrayString cpus = getFromList(_T("/Hosting/KnownMatchmakerCPU"));
+    std::set<int> ret;
+    for ( unsigned int i = 0; i < cpus.GetCount(); i++ )
+        ret.insert( FromwxString<int>(cpus[i]) );
+    return ret;
+}
+
+void Settings::AddKnownMatchmakerCPU(int cpu)
+{
+    std::set<int> current = KnownMatchmakerCPU();
+    current.insert(cpu);
+    wxArrayString new_cpus;
+    for (std::set<int>::const_iterator it = current.begin();
+         it != current.end(); ++it) {
+        new_cpus.Add( TowxString(*it) );
+    }
+    setFromList( new_cpus, _T("/Hosting/KnownMatchmakerCPU") );
+}
