@@ -3,10 +3,12 @@
 
 #include <wx/string.h>
 #include <vector>
+#include <set>
 #include "utils/mixins.hh"
+#include "utils/pathlistfactory.h"
 
 const int CACHE_VERSION     = 11;
-const int SETTINGS_VERSION  = 22;
+const int SETTINGS_VERSION  = 23;
 
 const wxString DEFSETT_DEFAULT_SERVER_NAME= _T("Official server");
 const wxString DEFSETT_DEFAULT_SERVER_HOST = _T("lobby.springrts.com");
@@ -382,11 +384,8 @@ class Settings : public SL::NonCopyable
      * @{
      */
 
-		wxPathList GetAdditionalSearchPaths( wxPathList& pl );
-
     void ConvertOldSpringDirsOptions();
-
-		void RefreshSpringVersionList();
+    void RefreshSpringVersionList();
     std::map<wxString, wxString> GetSpringVersionList() const; /// index -> version
     wxString GetCurrentUsedSpringIndex();
     void SetUsedSpringIndex( const wxString& index );
@@ -405,7 +404,7 @@ class Settings : public SL::NonCopyable
 	void SetUseSpringPathFromBundle( bool value );
 
     /// convenience wrappers to get current used version paths
-	wxString GetCurrentUsedUikeys();
+    wxString GetCurrentUsedUikeys();
     wxString GetCurrentUsedDataDir();
     wxString GetCurrentUsedUnitSync();
     wxString GetCurrentUsedBundle();
@@ -424,7 +423,7 @@ class Settings : public SL::NonCopyable
     void SetBundle( const wxString& index, const wxString& path );
 
     wxString AutoFindSpringBin();
-    wxString AutoFindUnitSync();
+    wxString AutoFindUnitSync( 	wxPathList pl = PathlistFactory::ConfigFileSearchPaths() ) const;
     wxString AutoFindBundle();
 	wxString AutoFindUikeys();
 
@@ -799,6 +798,12 @@ class Settings : public SL::NonCopyable
 	wxString GlobalConfigPath() const { return m_config ? m_config->GlobalConfigPath() : wxString(); }
 	wxString FinalConfigPath() const { return m_final_config_path; }
 
+    //! move weirdly saved lists to sane form
+    void ConvertLists();
+
+    std::set<int> KnownMatchmakerCPU();
+    void AddKnownMatchmakerCPU(int cpu);
+
   protected:
     bool IsSpringBin( const wxString& path );
 
@@ -810,9 +815,10 @@ class Settings : public SL::NonCopyable
 
     std::map<wxString, wxString> m_spring_versions;
 
-	wxPathList GetConfigFileSearchPathes();
-
 	wxString m_final_config_path;
+
+    void setFromList(const wxArrayString& list, const wxString& path);
+    wxArrayString getFromList(const wxString& path);
 };
 
 Settings& sett();
