@@ -35,7 +35,7 @@
 #include "qt/noguisingleplayerbattle.h"
 #include "offlinebattle.h"
 #include "user.h"
-#include "iunitsync.h"
+#include "springunitsync.h"
 #include "nonportable.h"
 #include "tdfcontainer.h"
 #ifndef NO_TORRENT_SYSTEM
@@ -110,7 +110,14 @@ bool Spring::Run( Battle& battle )
     battle.DisableHostStatusInProxyMode( false );
     f.Close();
 
-  } catch (...)
+  }
+    catch ( std::exception& e )
+    {
+        wxLogError( wxString::Format( _T("Couldn't write script.txt, exception caught:\n %s"), TowxString( e.what() ).c_str() ) );
+        return false;
+    }
+
+  catch (...)
   {
     wxLogError( _T("Couldn't write script.txt") );
     return false;
@@ -155,7 +162,13 @@ bool Spring::Run( SinglePlayerBattle& battle )
     f.Write( WriteScriptTxt(battle) );
     f.Close();
 
-  } catch (...)
+  }
+  catch ( std::exception& e )
+  {
+    wxLogError( wxString::Format( _T("Couldn't write script.txt, exception caught:\n %s"), TowxString( e.what() ).c_str() ) );
+    return false;
+  }
+  catch (...)
   {
     wxLogError( _T("Couldn't write script.txt") );
     return false;
@@ -231,7 +244,7 @@ bool Spring::LaunchSpring( const wxString& params  )
         cmd += sep + wxString(_T("Contents")) + sep + wxString(_T("MacOS")) + sep + wxString(_T("spring")); // append app bundle inner path
   #endif
   cmd += _T("\" ") + configfileflags + params;
-  
+
   wxLogMessage( _T("spring call params: %s"), cmd.c_str() );
 
 #ifdef SL_QT_MODE
@@ -417,6 +430,7 @@ wxString Spring::WriteScriptTxt( IBattle& battle ) const
 
 
 			tdf.EnterSection(_T("modoptions"));
+				tdf.Append( _T("relayhoststartpostype"), startpostype ); // also save the original wanted setting
 				OptionsWrapper::wxStringTripleVec optlistMod = battle.CustomBattleOptions().getOptions( OptionsWrapper::ModOption );
 				for (OptionsWrapper::wxStringTripleVec::const_iterator it = optlistMod.begin(); it != optlistMod.end(); ++it)
 				{
@@ -498,7 +512,7 @@ wxString Spring::WriteScriptTxt( IBattle& battle ) const
 					tdf.LeaveSection();
 					player_to_number[&user] = i;
 			}
-			if ( usync().VersionSupports( IUnitSync::USYNC_GetSkirmishAI ) )
+			if ( usync().VersionSupports( SpringUnitSync::USYNC_GetSkirmishAI ) )
 			{
 				for ( unsigned int i = 0; i < NumUsers; i++ )
 				{
@@ -541,7 +555,7 @@ wxString Spring::WriteScriptTxt( IBattle& battle ) const
 					parsedteams.insert( status.team );
 
 					tdf.EnterSection( _T("TEAM") + TowxString( teams_to_sorted_teams[status.team] ) );
-						if ( !usync().VersionSupports( IUnitSync::USYNC_GetSkirmishAI ) && status.IsBot() )
+						if ( !usync().VersionSupports( SpringUnitSync::USYNC_GetSkirmishAI ) && status.IsBot() )
 						{
 								tdf.Append( _T("AIDLL"), status.aishortname );
 								tdf.Append( _T("TeamLeader"), player_to_number[&battle.GetUser( status.owner )] ); // bot owner is the team leader
@@ -626,10 +640,10 @@ wxString Spring::WriteScriptTxt( IBattle& battle ) const
 							{
 									const char* old_locale = std::setlocale(LC_NUMERIC, "C");
 
-									tdf.Append( _T("StartRectLeft"), wxString::Format( _T("%.3f"), sr.left / 200.0 ) );
-									tdf.Append( _T("StartRectTop"), wxString::Format( _T("%.3f"), sr.top / 200.0 ) );
-									tdf.Append( _T("StartRectRight"), wxString::Format( _T("%.3f"), sr.right / 200.0 ) );
-									tdf.Append( _T("StartRectBottom"), wxString::Format( _T("%.3f"), sr.bottom / 200.0 ) );
+									tdf.Append( _T("StartRectLeft"), wxFormat( _T("%.3f") ) % ( sr.left / 200.0 ) );
+									tdf.Append( _T("StartRectTop"), wxFormat( _T("%.3f") ) % ( sr.top / 200.0 ) );
+									tdf.Append( _T("StartRectRight"), wxFormat( _T("%.3f") ) % ( sr.right / 200.0 ) );
+									tdf.Append( _T("StartRectBottom"), wxFormat( _T("%.3f") ) % ( sr.bottom / 200.0 ) );
 
 									std::setlocale(LC_NUMERIC, old_locale);
 							}
