@@ -67,10 +67,7 @@ const unsigned int TIMER_INTERVAL   = 100;
 IMPLEMENT_APP(SpringLobbyApp)
 
 BEGIN_EVENT_TABLE(SpringLobbyApp, wxApp)
-
     EVT_TIMER(TIMER_ID, SpringLobbyApp::OnTimer)
-
-
 END_EVENT_TABLE()
 
 SpringLobbyApp::SpringLobbyApp()
@@ -321,6 +318,7 @@ void SpringLobbyApp::OnInitCmdLine(wxCmdLineParser& parser)
     parser.SetSwitchChars (_T("-"));
 
     #undef STR
+    #undef CSTR
 }
 
 //! @brief parses the command line and sets global app options like log verbosity or log target
@@ -487,6 +485,11 @@ void SpringLobbyApp::CacheAndSettingsSetup()
 					}
 				}
 			}
+            if ( settversion < 23 )
+            {
+                sett().ConvertLists();
+                sett().AddKnownMatchmakerCPU(6667);
+            }
     }
 
     if ( sett().ShouldAddDefaultServerSettings() || ( sett().GetSettingsVersion() < 14 && sett().GetServers().Count() < 2  ) )
