@@ -72,40 +72,6 @@ Ui& ui()
     return m_ui;
 }
 
-ServerSelector::ServerSelector()
-	: m_serv(0)
-{}
-
-bool ServerSelector::GetServerStatus() const
-{
-	return (bool)(m_serv);
-}
-
-Server& ServerSelector::GetServer()
-{
-	ASSERT_LOGIC( m_serv != 0, _T("m_serv NULL!") );
-	return *m_serv;
-}
-
-const Server& ServerSelector::GetServer() const
-{
-	ASSERT_LOGIC( m_serv != 0, _T("m_serv NULL!") );
-	return *m_serv;
-}
-
-void ServerSelector::SetCurrentServer(Server* server)
-{
-	m_serv = server;
-	ASSERT_LOGIC( m_serv != 0, _T("m_serv NULL!") );
-}
-
-ServerSelector& serverSelector()
-{
-	static LineInfo<ServerSelector> m( AT );
-	static GlobalObjectHolder<ServerSelector,LineInfo<ServerSelector> > m_selector( m );
-	return m_selector;
-}
-
 Ui::Ui() :
         m_serv(0),
         m_main_win(0),
@@ -394,7 +360,12 @@ void Ui::DownloadFileP2P( const wxString& name )
 {
 #ifndef NO_TORRENT_SYSTEM
 	if ( usync().IsLoaded() )
+    {
+        wxFormat msg(_("Queued download of %s"));
+        UiEvents::GetStatusEventSender( UiEvents::addStatusMessage ).SendEvent(
+                    UiEvents::StatusData( (msg % name).str(), 1 ) );
 		torrent().RequestFileByName( name );
+    }
 	else
 	{
 		customMessageBoxNoModal( SL_MAIN_ICON, _("To use the integrated downloader the unitsync library needs to be loaded.\n" \
@@ -1407,16 +1378,7 @@ void Ui::FirstRunWelcome()
 		IntroGuide* intro = new IntroGuide();
 		intro->Show();
 
-		// copy uikeys.txt
-		wxPathList pl;
-		pl.AddEnvList( _T("%ProgramFiles%") );
-		pl.AddEnvList( _T("XDG_DATA_DIRS") );
-		pl = sett().GetAdditionalSearchPaths( pl );
-		wxString uikeyslocation = pl.FindValidPath( _T("uikeys.txt") );
-		if ( !uikeyslocation.IsEmpty() )
-		{
-			wxCopyFile( uikeyslocation, sett().GetCurrentUsedDataDir() + wxFileName::GetPathSeparator() + _T("uikeys.txt"), false );
-		}
+        CopyUikeys( sett().GetCurrentUsedDataDir() );
 
     #ifdef __WXMSW__
         if ( TASClientPresent() &&
