@@ -30,9 +30,14 @@
 	#include <QCoreApplication>
 	#include <QDir>
 #endif
+#include "pathlistfactory.h"
 
+//!This is only ever used for unitsync and on daftalx notice it should actually be .dylib (wx returns .bundle )
 wxString GetLibExtension()
 {
+#ifdef __APPLE__
+    return wxString(".dylib");
+#endif
     return wxDynamicLibrary::CanonicalizeName(_T(""), wxDL_MODULE);
 }
 
@@ -389,7 +394,7 @@ PwdGuard::~PwdGuard()
 wxString GetAppName( const bool lowerCase )
 {
 #ifdef SL_QT_MODE
-	wxString name = TowxString( QCoreApplication::applicationName );
+	wxString name = TowxString( QCoreApplication::applicationName() );
 #else
 	wxString name = wxTheApp->GetAppName();//this would segfault in qt mode
 #endif
@@ -407,7 +412,6 @@ wxString IdentityString(const wxString format, bool lowerCase )
 wxString AppendAppName(const wxString& dir)
 {
 	wxString subdir(dir);
-
 	// empty string indicates that an error has occurred, don't touch it then
 	if ( !subdir.empty() )
 	{
@@ -417,11 +421,9 @@ wxString AppendAppName(const wxString& dir)
 			const wxChar ch = *(subdir.end() - 1);
 			if ( !wxFileName::IsPathSeparator(ch) && ch != _T('.') )
 				subdir += wxFileName::GetPathSeparator();
-
 			subdir += appname;
 		}
 	}
-
 	return subdir;
 }
 
@@ -445,3 +447,12 @@ wxString GetCustomizedEngineConfigFilePath()
 	return path;
 }
 
+//! copy uikeys.txt
+void CopyUikeys( wxString currentDatadir )
+{
+    wxString uikeyslocation = PathlistFactory::UikeysLocations().FindValidPath( _T("uikeys.txt") );
+    if ( !uikeyslocation.IsEmpty() )
+    {
+        wxCopyFile( uikeyslocation, currentDatadir + wxFileName::GetPathSeparator() + _T("uikeys.txt"), false );
+    }
+}
