@@ -15,6 +15,7 @@
 #include "../utils/conversion.h"
 #include "downloadlistctrl.h"
 #include "infopanel.h"
+#include "../settings.h"
 
 const int invalid_id = -1;
 const unsigned int max_short_desc_length = 50;
@@ -79,19 +80,18 @@ void WidgetDownloadPanel::OnSelect( wxListEvent& event )
 
 bool WidgetDownloadPanel::PopulateList()
 {
-    bool success = true;
+	bool success = false;
 	wxHTTP http;
 
 	http.SetTimeout(6);
-	http.Connect(_T("spring.vsync.de"));
+	http.Connect(widgetDownloader_baseUrl);
         // PHP file sending XML content
-	wxInputStream *httpStream = http.GetInputStream(_T("/luaManager/lua_manager.php?m=0"));
+	wxInputStream *httpStream = http.GetInputStream(_T("/lua_manager.php?m=0"));
 
 	if (http.GetError() == wxPROTO_NOERR)
 	{
 		wxXmlDocument xml(*httpStream);
-
-		wxXmlNode *node = xml.GetRoot()->GetChildren();
+		wxXmlNode *node = xml.GetRoot() ? xml.GetRoot()->GetChildren() : NULL;
 		while (node)
 		{
 		    int id = FromwxString<long>( node->GetPropVal( _T("ID"), TowxString( invalid_id ) ) );
@@ -151,10 +151,9 @@ bool WidgetDownloadPanel::PopulateList()
             }
 
 			node = node->GetNext();
+			success = true;
 		}
 	}
-	else
-		success = false;
 
 	http.Close();
 	wxDELETE(httpStream);
