@@ -32,6 +32,7 @@
 #include "wx/menu.h"
 #include <list>
 #include "../settings++/hotkeys/CommandOrderDlg.h"
+#include "../utils/conversion.h"
 #include "../settings++/hotkeys/ChangeMetaDlg.h"
 
 
@@ -716,10 +717,10 @@ bool wxCmd::Save(wxConfigBase *p, const wxString &key, bool bCleanOld) const
         shortcuts += GetShortcut(j)->GetStr() + wxT("|");
 
     // write the entry in the format NAME|DESC|SHORTCUT1|SHORTCUT2...|SHORTCUTn
-    wxString value = wxString::Format(wxT("%s|%s|%s"),
-                                    GetName().c_str(),
-                                    GetDescription().c_str(),
-                                    shortcuts.c_str());
+	wxString value = wxFormat(wxT("%s|%s|%s") )
+									% GetName()
+									% GetDescription()
+									% shortcuts;
 
     // does the given key already exists ?
     if (bCleanOld && p->Exists(key))
@@ -971,8 +972,11 @@ bool wxKeyBinder::Save(wxConfigBase *cfg, const wxString &key, bool bCleanOld) c
         wxCmd *curr = m_arrCmd.Item(i);
 
         // write the key in the format: bindID-typeID
-        wxString keyname = wxString::Format(wxT("%s%s%d-type%d"),
-            basekey.c_str(), wxCMD_CONFIG_PREFIX, curr->GetId(), curr->GetType());
+		wxString keyname = wxFormat(wxT("%s%s%d-type%d") )
+									% basekey
+									% wxCMD_CONFIG_PREFIX
+									% curr->GetId()
+									% curr->GetType();
 
         // save this wxCmd...
         b &= curr->Save(cfg, keyname);
@@ -1219,7 +1223,7 @@ bool wxKeyProfileArray::Save(wxConfigBase *cfg, const wxString &key, bool bClean
 
         // save all our elements into a subkey of the given key
         b &= Item(i)->Save(cfg, basekey + wxKEYPROFILE_CONFIG_PREFIX +
-                                    wxString::Format(wxT("%d"), (int)i), bCleanOld);
+									wxFormat(wxT("%d") ) % (int)i, bCleanOld);
 
     // if required, remove any previously stored key profile...
     if (bCleanOld) {
@@ -1666,7 +1670,7 @@ wxTreeItemId wxKeyConfigPanel::FindTreeItem( wxTreeItemId root, const wxString&
 	while( item.IsOk() )
 	{
 		wxString sData = m_pCommandsTree->GetItemText(item);
-		if( sSearchFor.CompareTo(sData) == 0 )
+		if( sSearchFor.Cmp(sData) == 0 )
 		{
 			return item;
 		}
@@ -2196,9 +2200,9 @@ void wxKeyConfigPanel::OnProfileSelected(wxCommandEvent &e)
 
             // NB: m_nCurrentProf now retains the old profile index
             int choice = wxMessageBox(
-                wxString::Format(wxT("The previous profile (named \"%s\") has been modified.\n")
-                        wxT("Do you want to save the changes to that profile ?"),
-                        GetProfile(m_nCurrentProf)->GetName().c_str()),
+                wxFormat(wxT("The previous profile (named \"%s\") has been modified.\n")
+							wxT("Do you want to save the changes to that profile ?") )
+							% GetProfile(m_nCurrentProf)->GetName(),
                 wxT("Warning"), wxYES_NO | wxICON_QUESTION);
 
             if (choice == wxYES) {
@@ -2355,8 +2359,8 @@ void wxKeyConfigPanel::OnAssignKey(wxCommandEvent &)
     if (sel->GetShortcutCount() >= wxCMD_MAX_SHORTCUTS) {
 
         // sorry...
-        wxMessageBox(wxString::Format(wxT("Cannot add more than %d shortcuts ")
-                    wxT("to a single command..."), wxCMD_MAX_SHORTCUTS),
+        wxMessageBox(wxFormat(wxT("Cannot add more than %d shortcuts ")
+					wxT("to a single command...") ) % wxCMD_MAX_SHORTCUTS,
                     wxT("Cannot add another shortcut"));
         return;
     }
